@@ -10,9 +10,17 @@ class DistributeApp(ncdistributerlib.Distributor):
 This application will package a script for distribution.
 Usage:
     {appname} <filename>...
-    {appname} [--exclude-path=<path> --exclude-path=<path>] <filename>
+    {appname} [options] 
+              [--exclude-path=<path> --exclude-path=<path>] 
+              <filename>...
     {appname} -h | --help
 
+Options:
+    --hashbang=<string> The hashbang line to be placed at the 
+                        start of the zip file. 
+                        [default: #!/usr/bin/env python3] 
+
+
     """.format(appname=sys.argv[0])
 
     def run(self,):
@@ -22,6 +30,6 @@ Usage:
     
 if __name__ == "__main__":
     arguments = docopt.docopt(DistributeApp.__doc__)
-    A = DistributeApp(exclude_path_list=arguments["--exclude-path"])
+    A = DistributeApp(exclude_path_list=arguments["--exclude-path"], hashbang=arguments['--hashbang'])
     A.arguments = arguments
     A.run()
