@@ -26,11 +26,15 @@ class Distributor(object):
     working_directory = 'zipdist'
     included_path  = sys.path.extend(['.',])
     
-    def __init__(self, exclude_path_list=None):
+    def __init__(self, exclude_path_list=None, hashbang=False):
         self.excluded_paths = [get_python_lib(standard_lib=True), ]
         if exclude_path_list:
             for excl in exclude_path_list:
                 self.excluded_paths.append(excl)
+        if hashbang is False: 
+            self.hashbang = '#!/usr/bin/env python3'
+        else:
+            self.hashbang = hashbang
     
     def find_libraries(self, filename):
         """
@@ -84,7 +88,8 @@ Returns (modulename, module) for each of them.
                 
         
         with open(output_path, 'wb') as output_file:
-            output_file.write("#!/usr/bin/env python3\n".encode('ascii'))
+            if self.hashbang:
+                output_file.write("{}\n".format(self.hashbang).encode('ascii'))
             with open(working_zip_file, 'rb') as prepared_zip: 
                 data = prepared_zip.read()
                 output_file.write(data)
